==> distribution-6.0.0-dev.128.zip: drr/standards/iosco/upi/validation/exists/AnnaDsbOTHCOnlyExistsValidator.java <==
package drr.standards.iosco.upi.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.standards.iosco.upi.AnnaDsbEmpty;
import drr.standards.iosco.upi.AnnaDsbOTHC;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class AnnaDsbOTHCOnlyExistsValidator implements ValidatorWithArg<AnnaDsbOTHC, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends AnnaDsbOTHC> ValidationResult<AnnaDsbOTHC> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("DLVR", ExistenceChecker.isSet((AnnaDsbEmpty) o.getDLVR()))
				.put("NDLV", ExistenceChecker.isSet((AnnaDsbEmpty) o.getNDLV()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("AnnaDsbOTHC", ValidationType.ONLY_EXISTS, "AnnaDsbOTHC", path, "");
		}
		return failure("AnnaDsbOTHC", ValidationType.ONLY_EXISTS, "AnnaDsbOTHC", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}

==> distribution-7.0.0-dev.66.zip: drr/standards/iosco/upi/validation/exists/AnnaDsbOTHCOnlyExistsValidator.java <==
package drr.standards.iosco.upi.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.standards.iosco.upi.AnnaDsbEmpty;
import drr.standards.iosco.upi.AnnaDsbOTHC;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class AnnaDsbOTHCOnlyExistsValidator implements ValidatorWithArg<AnnaDsbOTHC, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends AnnaDsbOTHC> ValidationResult<AnnaDsbOTHC> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("DLVR", ExistenceChecker.isSet((AnnaDsbEmpty) o.getDLVR()))
				.put("NDLV", ExistenceChecker.isSet((AnnaDsbEmpty) o.getNDLV()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("AnnaDsbOTHC", ValidationResult.ValidationType.ONLY_EXISTS, "AnnaDsbOTHC", path, "");
		}
		return failure("AnnaDsbOTHC", ValidationResult.ValidationType.ONLY_EXISTS, "AnnaDsbOTHC", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}
